@@ -3,9 +3,9 @@ Main interface for datapipeline service type definitions.
 
 Usage::
 
-    from mypy_boto3.datapipeline.type_defs import CreatePipelineOutputTypeDef
+    from mypy_boto3.datapipeline.type_defs import FieldTypeDef
 
-    data: CreatePipelineOutputTypeDef = {...}
+    data: FieldTypeDef = {...}
 """
 import sys
 from typing import Dict, List
@@ -21,38 +21,36 @@ else:
 
 
 __all__ = (
-    "CreatePipelineOutputTypeDef",
     "FieldTypeDef",
-    "PipelineObjectTypeDef",
-    "DescribeObjectsOutputTypeDef",
-    "TagTypeDef",
-    "PipelineDescriptionTypeDef",
-    "DescribePipelinesOutputTypeDef",
-    "EvaluateExpressionOutputTypeDef",
+    "OperatorTypeDef",
     "ParameterAttributeTypeDef",
     "ParameterObjectTypeDef",
     "ParameterValueTypeDef",
-    "GetPipelineDefinitionOutputTypeDef",
-    "InstanceIdentityTypeDef",
+    "PipelineDescriptionTypeDef",
     "PipelineIdNameTypeDef",
-    "ListPipelinesOutputTypeDef",
-    "PaginatorConfigTypeDef",
+    "PipelineObjectTypeDef",
+    "SelectorTypeDef",
+    "TagTypeDef",
     "TaskObjectTypeDef",
-    "PollForTaskOutputTypeDef",
     "ValidationErrorTypeDef",
     "ValidationWarningTypeDef",
+    "CreatePipelineOutputTypeDef",
+    "DescribeObjectsOutputTypeDef",
+    "DescribePipelinesOutputTypeDef",
+    "EvaluateExpressionOutputTypeDef",
+    "GetPipelineDefinitionOutputTypeDef",
+    "InstanceIdentityTypeDef",
+    "ListPipelinesOutputTypeDef",
+    "PaginatorConfigTypeDef",
+    "PollForTaskOutputTypeDef",
     "PutPipelineDefinitionOutputTypeDef",
     "QueryObjectsOutputTypeDef",
-    "OperatorTypeDef",
-    "SelectorTypeDef",
     "QueryTypeDef",
     "ReportTaskProgressOutputTypeDef",
     "ReportTaskRunnerHeartbeatOutputTypeDef",
     "ValidatePipelineDefinitionOutputTypeDef",
 )
 
-CreatePipelineOutputTypeDef = TypedDict("CreatePipelineOutputTypeDef", {"pipelineId": str})
-
 _RequiredFieldTypeDef = TypedDict("_RequiredFieldTypeDef", {"key": str})
 _OptionalFieldTypeDef = TypedDict(
     "_OptionalFieldTypeDef", {"stringValue": str, "refValue": str}, total=False
@@ -63,12 +61,72 @@ class FieldTypeDef(_RequiredFieldTypeDef, _OptionalFieldTypeDef):
     pass
 
 
-PipelineObjectTypeDef = TypedDict(
-    "PipelineObjectTypeDef", {"id": str, "name": str, "fields": List[FieldTypeDef]}
+OperatorTypeDef = TypedDict(
+    "OperatorTypeDef",
+    {"type": Literal["EQ", "REF_EQ", "LE", "GE", "BETWEEN"], "values": List[str]},
+    total=False,
 )
 
+ParameterAttributeTypeDef = TypedDict("ParameterAttributeTypeDef", {"key": str, "stringValue": str})
+
+ParameterObjectTypeDef = TypedDict(
+    "ParameterObjectTypeDef", {"id": str, "attributes": List["ParameterAttributeTypeDef"]}
+)
+
+ParameterValueTypeDef = TypedDict("ParameterValueTypeDef", {"id": str, "stringValue": str})
+
+_RequiredPipelineDescriptionTypeDef = TypedDict(
+    "_RequiredPipelineDescriptionTypeDef",
+    {"pipelineId": str, "name": str, "fields": List["FieldTypeDef"]},
+)
+_OptionalPipelineDescriptionTypeDef = TypedDict(
+    "_OptionalPipelineDescriptionTypeDef",
+    {"description": str, "tags": List["TagTypeDef"]},
+    total=False,
+)
+
+
+class PipelineDescriptionTypeDef(
+    _RequiredPipelineDescriptionTypeDef, _OptionalPipelineDescriptionTypeDef
+):
+    pass
+
+
+PipelineIdNameTypeDef = TypedDict("PipelineIdNameTypeDef", {"id": str, "name": str}, total=False)
+
+PipelineObjectTypeDef = TypedDict(
+    "PipelineObjectTypeDef", {"id": str, "name": str, "fields": List["FieldTypeDef"]}
+)
+
+SelectorTypeDef = TypedDict(
+    "SelectorTypeDef", {"fieldName": str, "operator": "OperatorTypeDef"}, total=False
+)
+
+TagTypeDef = TypedDict("TagTypeDef", {"key": str, "value": str})
+
+TaskObjectTypeDef = TypedDict(
+    "TaskObjectTypeDef",
+    {
+        "taskId": str,
+        "pipelineId": str,
+        "attemptId": str,
+        "objects": Dict[str, "PipelineObjectTypeDef"],
+    },
+    total=False,
+)
+
+ValidationErrorTypeDef = TypedDict(
+    "ValidationErrorTypeDef", {"id": str, "errors": List[str]}, total=False
+)
+
+ValidationWarningTypeDef = TypedDict(
+    "ValidationWarningTypeDef", {"id": str, "warnings": List[str]}, total=False
+)
+
+CreatePipelineOutputTypeDef = TypedDict("CreatePipelineOutputTypeDef", {"pipelineId": str})
+
 _RequiredDescribeObjectsOutputTypeDef = TypedDict(
-    "_RequiredDescribeObjectsOutputTypeDef", {"pipelineObjects": List[PipelineObjectTypeDef]}
+    "_RequiredDescribeObjectsOutputTypeDef", {"pipelineObjects": List["PipelineObjectTypeDef"]}
 )
 _OptionalDescribeObjectsOutputTypeDef = TypedDict(
     "_OptionalDescribeObjectsOutputTypeDef", {"marker": str, "hasMoreResults": bool}, total=False
@@ -81,47 +139,21 @@ class DescribeObjectsOutputTypeDef(
     pass
 
 
-TagTypeDef = TypedDict("TagTypeDef", {"key": str, "value": str})
-
-_RequiredPipelineDescriptionTypeDef = TypedDict(
-    "_RequiredPipelineDescriptionTypeDef",
-    {"pipelineId": str, "name": str, "fields": List[FieldTypeDef]},
-)
-_OptionalPipelineDescriptionTypeDef = TypedDict(
-    "_OptionalPipelineDescriptionTypeDef",
-    {"description": str, "tags": List[TagTypeDef]},
-    total=False,
-)
-
-
-class PipelineDescriptionTypeDef(
-    _RequiredPipelineDescriptionTypeDef, _OptionalPipelineDescriptionTypeDef
-):
-    pass
-
-
 DescribePipelinesOutputTypeDef = TypedDict(
-    "DescribePipelinesOutputTypeDef", {"pipelineDescriptionList": List[PipelineDescriptionTypeDef]}
+    "DescribePipelinesOutputTypeDef",
+    {"pipelineDescriptionList": List["PipelineDescriptionTypeDef"]},
 )
 
 EvaluateExpressionOutputTypeDef = TypedDict(
     "EvaluateExpressionOutputTypeDef", {"evaluatedExpression": str}
 )
 
-ParameterAttributeTypeDef = TypedDict("ParameterAttributeTypeDef", {"key": str, "stringValue": str})
-
-ParameterObjectTypeDef = TypedDict(
-    "ParameterObjectTypeDef", {"id": str, "attributes": List[ParameterAttributeTypeDef]}
-)
-
-ParameterValueTypeDef = TypedDict("ParameterValueTypeDef", {"id": str, "stringValue": str})
-
 GetPipelineDefinitionOutputTypeDef = TypedDict(
     "GetPipelineDefinitionOutputTypeDef",
     {
-        "pipelineObjects": List[PipelineObjectTypeDef],
-        "parameterObjects": List[ParameterObjectTypeDef],
-        "parameterValues": List[ParameterValueTypeDef],
+        "pipelineObjects": List["PipelineObjectTypeDef"],
+        "parameterObjects": List["ParameterObjectTypeDef"],
+        "parameterValues": List["ParameterValueTypeDef"],
     },
     total=False,
 )
@@ -130,10 +162,8 @@ InstanceIdentityTypeDef = TypedDict(
     "InstanceIdentityTypeDef", {"document": str, "signature": str}, total=False
 )
 
-PipelineIdNameTypeDef = TypedDict("PipelineIdNameTypeDef", {"id": str, "name": str}, total=False)
-
 _RequiredListPipelinesOutputTypeDef = TypedDict(
-    "_RequiredListPipelinesOutputTypeDef", {"pipelineIdList": List[PipelineIdNameTypeDef]}
+    "_RequiredListPipelinesOutputTypeDef", {"pipelineIdList": List["PipelineIdNameTypeDef"]}
 )
 _OptionalListPipelinesOutputTypeDef = TypedDict(
     "_OptionalListPipelinesOutputTypeDef", {"marker": str, "hasMoreResults": bool}, total=False
@@ -150,27 +180,8 @@ PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
 )
 
-TaskObjectTypeDef = TypedDict(
-    "TaskObjectTypeDef",
-    {
-        "taskId": str,
-        "pipelineId": str,
-        "attemptId": str,
-        "objects": Dict[str, PipelineObjectTypeDef],
-    },
-    total=False,
-)
-
 PollForTaskOutputTypeDef = TypedDict(
-    "PollForTaskOutputTypeDef", {"taskObject": TaskObjectTypeDef}, total=False
-)
-
-ValidationErrorTypeDef = TypedDict(
-    "ValidationErrorTypeDef", {"id": str, "errors": List[str]}, total=False
-)
-
-ValidationWarningTypeDef = TypedDict(
-    "ValidationWarningTypeDef", {"id": str, "warnings": List[str]}, total=False
+    "PollForTaskOutputTypeDef", {"taskObject": "TaskObjectTypeDef"}, total=False
 )
 
 _RequiredPutPipelineDefinitionOutputTypeDef = TypedDict(
@@ -179,8 +190,8 @@ _RequiredPutPipelineDefinitionOutputTypeDef = TypedDict(
 _OptionalPutPipelineDefinitionOutputTypeDef = TypedDict(
     "_OptionalPutPipelineDefinitionOutputTypeDef",
     {
-        "validationErrors": List[ValidationErrorTypeDef],
-        "validationWarnings": List[ValidationWarningTypeDef],
+        "validationErrors": List["ValidationErrorTypeDef"],
+        "validationWarnings": List["ValidationWarningTypeDef"],
     },
     total=False,
 )
@@ -198,17 +209,7 @@ QueryObjectsOutputTypeDef = TypedDict(
     total=False,
 )
 
-OperatorTypeDef = TypedDict(
-    "OperatorTypeDef",
-    {"type": Literal["EQ", "REF_EQ", "LE", "GE", "BETWEEN"], "values": List[str]},
-    total=False,
-)
-
-SelectorTypeDef = TypedDict(
-    "SelectorTypeDef", {"fieldName": str, "operator": OperatorTypeDef}, total=False
-)
-
-QueryTypeDef = TypedDict("QueryTypeDef", {"selectors": List[SelectorTypeDef]}, total=False)
+QueryTypeDef = TypedDict("QueryTypeDef", {"selectors": List["SelectorTypeDef"]}, total=False)
 
 ReportTaskProgressOutputTypeDef = TypedDict("ReportTaskProgressOutputTypeDef", {"canceled": bool})
 
@@ -222,8 +223,8 @@ _RequiredValidatePipelineDefinitionOutputTypeDef = TypedDict(
 _OptionalValidatePipelineDefinitionOutputTypeDef = TypedDict(
     "_OptionalValidatePipelineDefinitionOutputTypeDef",
     {
-        "validationErrors": List[ValidationErrorTypeDef],
-        "validationWarnings": List[ValidationWarningTypeDef],
+        "validationErrors": List["ValidationErrorTypeDef"],
+        "validationWarnings": List["ValidationWarningTypeDef"],
     },
     total=False,
 )
